@@ -1,21 +1,15 @@
 import base64
 from . import *
+import logging
 
-# Create the logger for the SDK
-import logging, sys
-logging.basicConfig(stream=sys.stdout, level=logging.DEBUG)
-log = logging.Logger('GX_SDK')
-
-# logger_handler = logging.StreamHandler()
-# log.addHandler(logger_handler)
-# logger_handler.setFormatter(logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s'))
+log = logging.getLogger(LOGGER_NAME)
 
 
 class Authenticator:
     def __init__(self):
-        self.token = TOKEN
-        self.login = LOGIN
-        self.password = PASSWORD
+        self.token = config.token
+        self.login = config.login
+        self.password = config.password
 
     def get_token(self):
         if self.token is not None:
@@ -33,5 +27,5 @@ class Authenticator:
                 return d
 
             else:
-                log.error('No login or password provided, neither token can be read form environment variable.')
+                log.error('No login or password provided, neither token can be read from environment variable.')
                 raise Exception('Authentication issue : no credentials found')
