@@ -1,29 +1,23 @@
 from . import *
-from generalindex.Authenticator import Authenticator
+from .Authenticator import Authenticator
 import time
-import io, sys
+import io
 import requests
+import logging
 from urllib3.util.retry import Retry
 
+from .constants import USER_AGENT
 
-# Create the logger for the SDK - must write to stdout
-import logging
-logging.basicConfig(stream=sys.stdout, level=logging.DEBUG)
-log = logging.getLogger('GX_SDK')
-
-# logger_handler = logging.StreamHandler()
-# log.addHandler(logger_handler)
-# logger_handler.setFormatter(logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s'))
-
+log = logging.getLogger(LOGGER_NAME)
 
 class HTTPCaller:
     def __init__(self):
-        self.url = ENDPOINT
-        self.jobid = JOB_ID
-        self.eid = EID
+        self.url = config.endpoint
+        self.jobid = config.job_id
+        self.eid = config.eid
         self.token = Authenticator().get_token()
-        self.user_agent = 'GX_PythonSDK_V0.0.6'
-    
+        self.user_agent = USER_AGENT
+
     def set_headers(self, headers=None):
         if headers is None:
             headers = {}
@@ -34,7 +28,6 @@ class HTTPCaller:
         return headers
 
     def post(self, path, payload=None, data=None, headers=None):
-
         headers = self.set_headers(headers)
 
         log.debug(f'Sending POST request to {path}, with payload: {payload}')
@@ -48,8 +41,8 @@ class HTTPCaller:
             return r
 
     def get(self, path, headers=None):
-
         headers = self.set_headers(headers)
+
         # Request URL
         full_path = self.url + path
         log.debug('GET request before sending: {}, {}'.format(full_path, headers))
@@ -60,14 +53,14 @@ class HTTPCaller:
         s = requests.Session()
 
         # Define your retries for http and https urls
-        http_retries = Retry(backoff_factor=0.1, total=5)
-        https_retries = Retry(backoff_factor=0.1, total=5)
+        http_retries = Retry(backoff_factor=0.1, total=5, status_forcelist = [104, 413, 429, 503, 502, 500])
+        https_retries = Retry(backoff_factor=0.1, total=5, status_forcelist = [104, 413, 429, 503, 502, 500])
 
         # Create adapters with the retry logic for each
         http = requests.adapters.HTTPAdapter(max_retries=http_retries)
         https = requests.adapters.HTTPAdapter(max_retries=https_retries)
 
-        # Replace the session’s original adapters
+        # Replace the sessions original adapters
         s.mount('http://', http)
         s.mount('https://', https)
 
@@ -86,8 +79,6 @@ class HTTPCaller:
             log.error('Data reception from {} ended with error (error code: {}). Response: {}'.format(path, r.status_code, r.text))
             return r
 
-
-
     def file_uploader(self, payload, file, headers=None):
         '''
         Uploads a file from disk or an object from RAM to datalake with a PUT function
@@ -114,12 +105,14 @@ class HTTPCaller:
             file_content = file
 
         else:
-            raise TypeError('Passed file argument must be either a file path to a file saved on the disk, either a io.BytesIO object to stream from memory')
+            raise TypeError(
+                'Passed file argument must be either a file path to a file saved on the disk, '
+                'either a io.BytesIO object to stream from memory')
 
         # PUT request
         r = requests.put(url,
                          data=file_content,
-                         headers={'Content-Type': 'application/octet-stream'}
+                         headers={'Content-Type': 'application/octet-stream', "User-Agent": self.user_agent}
                          )
 
         log.debug(f'PUT {r.url} \nHEADERS: {r.request.headers}')
@@ -151,22 +144,20 @@ class HTTPCaller:
 
         return file_id
 
-
-
     def get_from_S3(self, S3path):
 
         # Create a session
         s = requests.Session()
 
         # Define your retries for http and https urls
-        http_retries = Retry(backoff_factor=0.1, total=5)
-        https_retries = Retry(backoff_factor=0.1, total=5)
+        http_retries = Retry(backoff_factor=0.1, total=5, status_forcelist = [413, 429, 503, 502, 500])
+        https_retries = Retry(backoff_factor=0.1, total=5, status_forcelist = [413, 429, 503, 502, 500])
 
         # Create adapters with the retry logic for each
         http = requests.adapters.HTTPAdapter(max_retries=http_retries)
         https = requests.adapters.HTTPAdapter(max_retries=https_retries)
 
-        # Replace the session’s original adapters
+        # Replace the sessions original adapters
         s.mount('http://', http)
         s.mount('https://', https)
 
@@ -179,5 +170,7 @@ class HTTPCaller:
             return r
 
         else:
-            log.error('File download from {} ended with error (error code: {}). Response: {}'.format(S3path, r.status_code, r.text))
+            log.error(
+                'File download from {} ended with error (error code: {}). Response: {}'.format(S3path, r.status_code,
+                                                                                               r.text))
             return r
