@@ -1,16 +1,9 @@
-from . import JOB_ID, EID, COMPONENT_NAME, GROUP_NAME
+from . import LOGGER_NAME, config
 from .HTTPCalller import HTTPCaller
 import time
+import logging
 
-# Create the logger for the SDK
-import logging, sys
-logging.basicConfig(stream=sys.stdout, level=logging.DEBUG)
-log = logging.getLogger('GX_SDK')
-
-# logger_handler = logging.StreamHandler()
-# log.addHandler(logger_handler)
-# logger_handler.setFormatter(logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s'))
-
+log = logging.getLogger(LOGGER_NAME)
 
 class StatusHandler:
     '''
@@ -23,10 +16,10 @@ class StatusHandler:
 
     def __init__(self):
         self.caller = HTTPCaller()
-        self.eid = EID
-        self.job_id = JOB_ID
-        self.component_name = COMPONENT_NAME
-        self.group_name = GROUP_NAME
+        self.eid = config.eid
+        self.job_id = config.job_id
+        self.component_name = config.component_name
+        self.group_name = config.group_name
 
     def send_status(self, status, message):
         # Set the api call for the status connected to the new log event
