@@ -1,26 +1,18 @@
 import json
+import os
 import re
-import os, sys
 
-from . import PIPELINE_ID
+from . import LOGGER_NAME, config
 from .DatalakeHandler import *
 from .HTTPCalller import HTTPCaller
 from ast import literal_eval
 
-# Create the logger for the SDK
-import logging
-logging.basicConfig(stream=sys.stdout, level=logging.DEBUG)
-log = logging.getLogger('GX_SDK')
-
-# logger_handler = logging.StreamHandler()
-# log.addHandler(logger_handler)
-# logger_handler.setFormatter(logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s'))
-
+log = logging.getLogger(LOGGER_NAME)
 
 
 class TaskHandler:
     def __init__(self):
-        self.pipeline_id = PIPELINE_ID
+        self.pipeline_id = config.pipeline_id
         self.caller = HTTPCaller()
         self.main_path = os.getcwd()
 
@@ -181,7 +173,7 @@ class TaskHandler:
 
 
 
-    def upload_to_output_parameter(self, output_name, file, group_name, file_upload_name=None, file_type='SOURCE'):
+    def upload_to_output_parameter(self, output_name, file, group_name, file_upload_name=None, file_type='SOURCE', partial_update=False):
         '''
         Upload the file to the datalake as the Output of the TASK
         and pass its ID in the Storage for the next TASK input
@@ -200,7 +192,8 @@ class TaskHandler:
         file_id, file_name = uploader.upload_file(file=file,
                                                   group_name=group_name,
                                                   file_upload_name=file_upload_name,
-                                                  file_type=file_type)
+                                                  file_type=file_type,
+                                                  partial_update = partial_update)
 
         log.debug('File {} uploaded to {} with ID {}'.format(file, group_name, file_id))
 
