@@ -1,20 +1,13 @@
 import csv
-from datetime import datetime
+import os
 import json
-import urllib
 
+from datetime import datetime
+from . import LOGGER_NAME
 from .HTTPCalller import HTTPCaller
 from .DatalakeHandler import *
 
-# Create the logger for the SDK
-import logging, sys
-logging.basicConfig(stream=sys.stdout, level=logging.DEBUG)
-log = logging.getLogger('GX_SDK')
-
-# logger_handler = logging.StreamHandler()
-# log.addHandler(logger_handler)
-# logger_handler.setFormatter(logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s'))
-
+log = logging.getLogger(LOGGER_NAME)
 
 
 class Timeseries:
@@ -22,30 +15,42 @@ class Timeseries:
         self.caller = HTTPCaller()
         self.uploader = DatalakeHandler()
 
-
-    def get_symbols(self, group_name, _size=1000, _from=0):
+    def get_symbols(self, search_for: str=None, group_name: str = None, _size=1000, _from=0):
         '''
-        Returns a list of the symbols available on a given group
+        Returns a list of the symbols available on a given group or symbols within search
         '''
+        formatted_search = None
+        formatted_group = None
 
-        # Format the group name for url
-        formatted_group = urllib.parse.quote(group_name)
+        assert (group_name not in ["", None]) or (search_for not in ["", None]), 'Please specify either group_name or search_for parameter of get_symbols() method'
 
-        # Query URL
-        query_url = '/ts/symbol/search?size={}&from={}&query=groupName={}'.format(_size, _from, formatted_group)
+        # format group name and search for url - changes spaces to %20 etc.
+        if group_name not in ["", None]:
+            formatted_group = urllib.parse.quote(group_name)
+        if search_for not in ["", None]:
+            formatted_search = urllib.parse.quote(search_for)
+
+
+        if formatted_search is not None and formatted_group is not None:
+            # both search and group passed
+            query_url = '/ts/symbol/search?size={}&from={}&query={}*%26groupName.keyword%3D{}'.format(_size, _from, formatted_search, formatted_group)
+        elif formatted_search is not None and formatted_group is None:
+            # search passed
+            query_url = '/ts/symbol/search?size={}&from={}&query={}'.format(_size, _from, formatted_search)
+        else:
+            # group passed
+            query_url = '/ts/symbol/search?size={}&from={}&query=groupName.keyword%3D{}'.format(_size, _from, formatted_search, formatted_group)
+            
 
         # GET Request
         r = self.caller.get(path=query_url)
 
-        return json.load(io.BytesIO(self.caller.get(path=query_url).content))
-
-
-
-
+        return json.load(io.BytesIO(r.content))
 
     def retrieve_data_as_csv(self, symbols: dict, columns, group_name: str,
                              file_name: str = None, start_date: str = None, end_date: str = None,
-                             timezone: str = None, metadata: bool = False, allow_wildcard: bool = False, NCSV: bool = True,
+                             timezone: str = None,
+                             metadata: bool = False, allow_wildcard: bool = False, NCSV: bool = True,
                              corrections : str = 'false', delta: bool = False):
 
         '''
@@ -63,6 +68,8 @@ class Timeseries:
 
         :param: timezone: timezone as string used for the timestamps in the Date column. Continent/City, for example Europe/London
                         if None, it returns the date with the default timezone of the user, set in the application
+        :param: corrections: How to handle corrections in time series. Must be either "true", "false" or "only"
+        :param: delta: delta will filter timeseries by insertion date instead of the actual timestamp of data
         :param: metadata: boolean to return or not the metadata in the file, default as False
         :param: allow_wildcard: boolean to allow or not the use of wildcards '*' in the keys or columns
         :param: corrections: How to handle corrections in time series. Must be either "true", "false", "history" or "only"
@@ -120,7 +127,6 @@ class Timeseries:
                 ],
                 "corrections": corrections,
                 "delta": delta,
-               
                 "formatType": "NCSV" if NCSV else 'PANDAS'
                 }
 
@@ -128,7 +134,7 @@ class Timeseries:
         if timezone is not None:
             # Check the format for the timezone
             assert '/' in timezone, 'Wrongly formatted timezone argument. Must be for example Europe/London'
-
+ 
             # return dates in wanted timezone
             body["timeZone"] = timezone
 
@@ -198,10 +204,6 @@ class Timeseries:
 
         return
 
-
-
-
-
     def upload_data(self, file_name, symbols_columns, date_column, group_name):
         '''
         The methods uploads data to Timeseries by re-arranging the columns order and uploading the new file as NCSV.
